@@ -10,7 +10,7 @@ from msmart.security import security
 # The Midea cloud client is by far the more obscure part of this library, and without some serious reverse engineering
 # this would not have been possible. Thanks Yitsushi for the ruby implementation. This is an adaptation to Python 3
 
-VERSION = '0.1.16'
+VERSION = '0.1.17'
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -27,7 +27,7 @@ class lan:
     def request(self, message):
         # Create a TCP/IP socket
         sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        sock.settimeout(10)
+        sock.settimeout(8)
 
         # Connect the Device
         device_address = (self.device_ip, self.device_port)
@@ -75,7 +75,10 @@ class lan:
     def appliance_transparent_send(self, data):
         response = bytearray(self.request(data))
         if len(response) > 0:
-            reply = self.decode(self.security.aes_decrypt(response[40:88]))
+            if len(response) == 88:
+                reply = self.decode(self.security.aes_decrypt(response[40:72]))
+            else:
+                reply = self.decode(self.security.aes_decrypt(response[40:88]))
             return reply
         else:
             return bytearray(0)
